# (ngompa): Disable Dist-Git and OBS releasers for now
# We need to get fedora tools and osc in to enable them
%bcond_with distgit
%bcond_with obs

# Fedora release numbers are part of upstream tags
%global origrel 1

Name: tito
Version: 0.6.10
Release: %mkrel 1
Summary: A tool for managing rpm based git projects

Group: Development/Tools
License: GPLv2
URL: https://github.com/dgoodwin/tito
Source0: %{url}/archive/%{name}-%{version}-%{origrel}.tar.gz

# Switch to createrepo_c for repo generation
# From: https://github.com/dgoodwin/tito/pull/276
Patch0: 0001-Use-createrepo_c-for-creating-rpm-md-repos.patch

BuildArch: noarch

BuildRequires: asciidoc
BuildRequires: docbook-style-xsl
BuildRequires: xsltproc
BuildRequires: rpmdevtools
BuildRequires: rpm-build
BuildRequires: createrepo_c
BuildRequires: tar
BuildRequires: which
BuildRequires: git

BuildRequires: python3-devel
BuildRequires: python3-setuptools
BuildRequires: python3-bugzilla
BuildRequires: python3-rpm

Requires: python3-setuptools
Requires: python3-bugzilla
Requires: python3-blessings
Requires: python3-rpm

Requires: rpm-build
Requires: rpmlint
Requires: rpmdevtools
Requires: dnf-plugins-core

# For YumRepoReleaser
Requires: createrepo_c
# For CoprReleaser
Requires: copr-cli

%if %{with distgit}
# For FedoraGitReleaser
Requires: fedpkg
Requires: fedora-cert
Requires: fedora-packager
%endif

%if %{with obs}
# For ObsReleaser
Requires: osc
%endif


# Cheetah doesn't exist for Python 3, but it's what Mead uses.  We
# install it and call via the command line instead of importing the
# potentially incompatible code
Requires: python-cheetah

%description
Tito is a tool for managing tarballs, rpms, and builds for projects using
git.

%prep
%autosetup -p1 -n %{name}-%{name}-%{version}-%{origrel}

# Write the Python 3 interpreter path
sed -i 1"s|#!.*|#!%{__python3}|" bin/tito

%build
%py3_build

# convert manages
a2x -d manpage -f manpage titorc.5.asciidoc
a2x -d manpage -f manpage tito.8.asciidoc
a2x -d manpage -f manpage tito.props.5.asciidoc
a2x -d manpage -f manpage releasers.conf.5.asciidoc

%install
%py3_install

# manpages
%{__mkdir_p} %{buildroot}%{_mandir}/man5
%{__mkdir_p} %{buildroot}%{_mandir}/man8
cp -a titorc.5 tito.props.5 releasers.conf.5 %{buildroot}/%{_mandir}/man5/
cp -a tito.8 %{buildroot}/%{_mandir}/man8/
# bash completion facilities
install -Dp -m 0644 share/tito_completion.sh %{buildroot}%{_datadir}/bash-completion/completions/tito

%if %{without distgit}
find %{buildroot} -name "*distgit*" | xargs rm -fv
%endif

%if %{without obs}
find %{buildroot} -name "*obs*" | xargs rm -fv
%endif


%files
%license COPYING
%doc AUTHORS
%doc doc/*
%doc %{_mandir}/man5/titorc.5*
%doc %{_mandir}/man5/tito.props.5*
%doc %{_mandir}/man5/releasers.conf.5*
%doc %{_mandir}/man8/tito.8*
%{_bindir}/tito
%{_bindir}/generate-patches.pl
%{_datadir}/bash-completion/completions/tito
%{python3_sitelib}/tito
%{python3_sitelib}/tito*py?.?.egg-info



%changelog
* Sat Apr 08 2017 ngompa <ngompa> 0.6.10-1.mga6
+ Revision: 1096135
- Update to 0.6.10
- Switch to createrepo_c for YumRepoReleaser
- Add missing Requires for YumRepoReleaser and CoprReleaser

* Tue Oct 11 2016 ngompa <ngompa> 0.6.7-1.mga6
+ Revision: 1060156
- Update to 0.6.7

* Sun Apr 24 2016 ngompa <ngompa> 0.6.6-2.mga6
+ Revision: 1005938
- imported package tito

